pub enum RecordedOp {
RevealNodes {
nodes: Vec<ProofTrieNodeRecord>,
},
UpdateLeaves {
updates: Vec<(B256, LeafUpdateRecord)>,
proof_targets: Vec<(B256, u8)>,
},
UpdateSubtrieHashes,
Root,
SetRoot {
node: ProofTrieNodeRecord,
},
Prune,
}Expand description
A mutating operation recorded from a sparse trie.
Variants
RevealNodes
Records a reveal_nodes call with the nodes that were revealed.
Fields
nodes: Vec<ProofTrieNodeRecord>The proof trie nodes that were revealed.
UpdateLeaves
Records an update_leaves call with the leaf updates.
Fields
updates: Vec<(B256, LeafUpdateRecord)>The leaf updates that were applied.
UpdateSubtrieHashes
Records an update_subtrie_hashes call.
Root
Records a root() call.
SetRoot
Records a set_root call with the root node that was set.
Fields
node: ProofTrieNodeRecordThe root trie node that was set.
Prune
Records a prune call. Emitted before the post-prune SetRoot/RevealNodes
so consumers know the following initial state is the result of pruning.