pub enum SparseNodeState {
Dirty,
Cached {
rlp_node: RlpNode,
store_in_db_trie: Option<bool>,
},
}Expand description
Tracks the current state of a node in the trie, specifically regarding whether it’s been updated or not.
Variants
Dirty
The node has been updated and its new RlpNode has not yet been calculated.
If a node is dirty and has children (branches or extensions) then at least once child must also be dirty.
Cached
The node has a cached RlpNode, either from being revealed or computed after an update.
Fields
rlp_node: RlpNodeThe RLP node which is used to represent this node in its parent. Usually this is the RLP encoding of the node’s hash, except for when the node RLP encodes to <32 bytes.
Implementations
Sourceimpl SparseNodeState
impl SparseNodeState
Sourcepub const fn cached_rlp_node(&self) -> Option<&RlpNode>
pub const fn cached_rlp_node(&self) -> Option<&RlpNode>
Returns the cached [RlpNode] of the node, if it’s available.
Sourcepub fn cached_hash(&self) -> Option<B256>
pub fn cached_hash(&self) -> Option<B256>
Returns the cached hash of the node, if it’s available.
Sourcepub const fn store_in_db_trie(&self) -> Option<bool>
pub const fn store_in_db_trie(&self) -> Option<bool>
Returns whether or not this node is stored in the db, or None if it’s not known.