pub type SparseTrieUpdates = Vec<(Nibbles, Option<BranchNodeCompact>)>;Expand description
Chronological updates to persisted branches, with None indicating removal.
SparseTrie::take_updates sorts these by path and retains the latest update for each path.
Aliased Type
pub struct SparseTrieUpdates { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 24 bytes